==> rust-clap-help_1.2.0.orig.tar.gz: clap-help-1.2.0/CHANGELOG.md <==
<a name="1.2.0"></a>
### v1.2.0 - 2024-03-05
- `TEMPLATE_OPTIONS_MERGED_VALUE` alterate options template, easier to read and more compact for most applications

<a name="1.1.2"></a>
### v1.1.2 - 2024-02-29
- fix some unwanted possible values and default values with clap 4.4.14+ - Fix #2

<a name="1.1.1"></a>
### v1.1.1 - 2024-01-29
- list items indented as blocks

<a name="1.1.0"></a>
### v1.1.0 - 2024-01-18
- update termimad dependency to 0.28

<a name="1.0.0"></a>
### v1.0.0 - 2023-09-02
- clap-help is ready for 1.0 - no change is planned

<a name="v0.7.0"></a>
### v0.7.0 - 2023-08-20
- upgrade termimad to 0.25 for `skin.limit_to_ascii` (see with-examples example)

<a name="v0.6.2"></a>
### v0.6.2 - 2023-08-03
- fix template_order_mut not returning a mut reference. Rename the method to template_keys_mut
- demonstrate how to add Examples with a template after the Options table

<a name="v0.6.1"></a>
### v0.6.1 - 2023-08-02
- `set_max_width` forces wrapping for a width smaller than the terminal's width

<a name="v0.6.0"></a>
### v0.6.0 - 2023-08-02
- place centered titles based on the content's width, not the terminal's width

<a name="v0.5.0"></a>
### v0.5.0 - 2023-07-18
- add `--` before the last args

<a name="v0.4.0"></a>
### v0.4.0 - 2023-07-16
- templates and their order can be completely customized

<a name="v0.3.0"></a>
### v0.3.0 - 2023-07-16
- optional positional arguments displayed between square braces

<a name="v0.2.0"></a>
### v0.2.0 - 2023-07-16
- value column
- option to show or not author

<a name="v0.1.0"></a>
### v0.1.0 - 2023-07-15
- first release

==> rust-clap-help_1.3.1.orig.tar.gz: clap-help-1.3.1/CHANGELOG.md <==
<a name="1.3.1"></a>
### v1.3.1 - 2024-10-26
- update Termimad to 0.31

<a name="1.3.0"></a>
### v1.3.0 - 2024-08-12
- update Termimad to 0.30

<a name="1.2.0"></a>
### v1.2.0 - 2024-03-05
- `TEMPLATE_OPTIONS_MERGED_VALUE` alterate options template, easier to read and more compact for most applications

<a name="1.1.2"></a>
### v1.1.2 - 2024-02-29
- fix some unwanted possible values and default values with clap 4.4.14+ - Fix #2

<a name="1.1.1"></a>
### v1.1.1 - 2024-01-29
- list items indented as blocks

<a name="1.1.0"></a>
### v1.1.0 - 2024-01-18
- update termimad dependency to 0.28

<a name="1.0.0"></a>
### v1.0.0 - 2023-09-02
- clap-help is ready for 1.0 - no change is planned

<a name="v0.7.0"></a>
### v0.7.0 - 2023-08-20
- upgrade termimad to 0.25 for `skin.limit_to_ascii` (see with-examples example)

<a name="v0.6.2"></a>
### v0.6.2 - 2023-08-03
- fix template_order_mut not returning a mut reference. Rename the method to template_keys_mut
- demonstrate how to add Examples with a template after the Options table

<a name="v0.6.1"></a>
### v0.6.1 - 2023-08-02
- `set_max_width` forces wrapping for a width smaller than the terminal's width

<a name="v0.6.0"></a>
### v0.6.0 - 2023-08-02
- place centered titles based on the content's width, not the terminal's width

<a name="v0.5.0"></a>
### v0.5.0 - 2023-07-18
- add `--` before the last args

<a name="v0.4.0"></a>
### v0.4.0 - 2023-07-16
- templates and their order can be completely customized

<a name="v0.3.0"></a>
### v0.3.0 - 2023-07-16
- optional positional arguments displayed between square braces

<a name="v0.2.0"></a>
### v0.2.0 - 2023-07-16
- value column
- option to show or not author

<a name="v0.1.0"></a>
### v0.1.0 - 2023-07-15
- first release
